@@ -6,7 +6,7 @@ use Kwiki::Installer '-base';
 use YAML;
 use DBI;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 const class_id => 'comments';
 const class_title => 'Kwiki Comments';
@@ -103,6 +103,33 @@ __DATA__
 
 Kwiki::Comments - Post comments to a page
 
+=head1 DESCRIPTION
+
+B<Kwiki::Comments> is a L<Kwiki> plugin that allow anyone to leave
+comments to a Page, just like Slash comments or MT comments. To use
+this plugin, simply install L<Kwiki>, and this module from CPAN, and
+do:
+
+    # echo 'Kwiki::Comments' >> plugins
+    # kwiki -update
+
+Currently you'll need to have L<DBD::SQLite> module installed to use
+this module. Maybe in the future, we can support mor kind of database
+back-end.
+
+And now your site is ready to have comments. But, comments
+are not shown automatically. You'll have to append this line:
+
+    {comments}
+
+To whatever pages that are allow comment.
+
+The basic idea is that, some wiki pages can be protected, only admin
+can edit them. On those protected pages, comments becomes the only way
+for anybody to give feedbacks, but sometimes you don't even want a
+feedback. That's why you'll need to clearly specify if you want
+a comment form attach to the page, or not.
+
 =head1 COPYRIGHT
 
 Copyright 2004 by Kang-min Liu <gugod@gugod.org>.
@@ -113,6 +140,16 @@ modify it under the same terms as Perl itself.
 See <http://www.perl.com/perl/misc/Artistic.html>
 
 =cut
+__css/comments.css__
+.comments-body {
+	font-family:verdana, arial, sans-serif;
+	color:#666;
+	font-size:small;
+	line-height:140%;
+	padding-bottom:10px;
+	padding-top:10px;
+	border-bottom:1px dotted #999;
+}
 __template/tt2/comments_display.html__
 <!-- BEGIN comments_display.html -->
 <hr />
@@ -126,6 +163,7 @@ __template/tt2/comments_display.html__
 [% link = '' %]
 [% END %]
 <div class="comments-body">
+<p>[% post.text %]</p>
 <span class="comments-post">Posted by
 [% IF link %]
     <a href="[% link %]">[% post.author%]</a>
@@ -133,7 +171,6 @@ __template/tt2/comments_display.html__
     [% post.author %]
 [% END %]
 </span>
-<p>[% post.text %]</p>
 </div>
 [% END %]
 </div>
